@@ -6,6 +6,7 @@ import (
 	"time"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/ansi"
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
@@ -252,9 +253,14 @@ func (e *Engine) renderBlock(block *Block, cancelNewline bool) {
 
 // debug will loop through your config file and output the timings for each segments
 func (e *Engine) PrintDebug(startTime time.Time, version string) string {
-	var segmentTimings []*SegmentTiming
-	e.write(fmt.Sprintf("\n\x1b[38;2;191;207;240m\x1b[1mVersion:\x1b[0m %s\n", version))
-	e.write("\n\x1b[38;2;191;207;240m\x1b[1mSegments:\x1b[0m\n\n")
+	e.write(fmt.Sprintf("\n%s %s\n", log.Text("Version:").Green().Bold().Plain(), version))
+	sh := e.Env.Shell()
+	shellVersion := e.Env.Getenv("POSH_SHELL_VERSION")
+	if len(shellVersion) != 0 {
+		sh += fmt.Sprintf(" (%s)", shellVersion)
+	}
+	e.write(fmt.Sprintf("\n%s %s\n", log.Text("Shell:").Green().Bold().Plain(), sh))
+	e.write(log.Text("\nSegments:\n\n").Green().Bold().Plain().String())
 	// console title timing
 	titleStartTime := time.Now()
 	title := e.getTitleTemplateText()
@@ -266,6 +272,7 @@ func (e *Engine) PrintDebug(startTime time.Time, version string) string {
 		duration:   time.Since(titleStartTime),
 	}
 	largestSegmentNameLength := consoleTitleTiming.nameLength
+	var segmentTimings []*SegmentTiming
 	segmentTimings = append(segmentTimings, consoleTitleTiming)
 	// cache a pointer to the color cycle
 	cycle = &e.Config.Cycle
@@ -283,19 +290,19 @@ func (e *Engine) PrintDebug(startTime time.Time, version string) string {
 	largestSegmentNameLength += 22 + 7
 	for _, segment := range segmentTimings {
 		duration := segment.duration.Milliseconds()
-		var active string
+		var active log.Text
 		if segment.active {
-			active = "\x1b[38;2;156;231;201mtrue\x1b[0m"
+			active = log.Text("true").Yellow()
 		} else {
-			active = "\x1b[38;2;204;137;214mfalse\x1b[0m"
+			active = log.Text("false").Purple()
 		}
-		segmentName := fmt.Sprintf("%s(%s)", segment.name, active)
+		segmentName := fmt.Sprintf("%s(%s)", segment.name, active.Plain())
 		e.write(fmt.Sprintf("%-*s - %3d ms - %s\n", largestSegmentNameLength, segmentName, duration, segment.text))
 	}
-	e.write(fmt.Sprintf("\n\x1b[38;2;191;207;240m\x1b[1mRun duration:\x1b[0m %s\n", time.Since(startTime)))
-	e.write(fmt.Sprintf("\n\x1b[38;2;191;207;240m\x1b[1mCache path:\x1b[0m %s\n", e.Env.CachePath()))
-	e.write(fmt.Sprintf("\n\x1b[38;2;191;207;240m\x1b[1mConfig path:\x1b[0m %s\n", e.Env.Flags().Config))
-	e.write("\n\x1b[38;2;191;207;240m\x1b[1mLogs:\x1b[0m\n\n")
+	e.write(fmt.Sprintf("\n%s %s\n", log.Text("Run duration:").Green().Bold().Plain(), time.Since(startTime)))
+	e.write(fmt.Sprintf("\n%s %s\n", log.Text("Cache path:").Green().Bold().Plain(), e.Env.CachePath()))
+	e.write(fmt.Sprintf("\n%s %s\n", log.Text("Config path:").Green().Bold().Plain(), e.Env.Flags().Config))
+	e.write(log.Text("\nLogs:\n\n").Green().Bold().Plain().String())
 	e.write(e.Env.Logs())
 	return e.string()
 }
@@ -336,7 +343,9 @@ func (e *Engine) print() string {
 		}
 		// in bash, the entire rprompt needs to be escaped for the prompt to be interpreted correctly
 		// see https://github.com/jandedobbeleer/oh-my-posh/pull/2398
-		writer := &ansi.Writer{}
+		writer := &ansi.Writer{
+			TrueColor: e.Env.Flags().TrueColor,
+		}
 		writer.Init(shell.GENERIC)
 		prompt := writer.SaveCursorPosition()
 		prompt += writer.CarriageForward()
@@ -463,7 +472,13 @@ func (e *Engine) PrintExtraPrompt(promptType ExtraPromptType) string {
 			return prompt
 		}
 		return str
-	case shell.PWSH, shell.PWSH5, shell.CMD, shell.BASH, shell.FISH, shell.NU, shell.GENERIC:
+	case shell.PWSH, shell.PWSH5:
+		// Return the string and empty our buffer
+		str, _ := e.Writer.String()
+		// clear the line afterwards to prevent text from being written on the same line
+		// see https://github.com/JanDeDobbeleer/oh-my-posh/issues/3628
+		return str + e.Writer.ClearAfter()
+	case shell.CMD, shell.BASH, shell.FISH, shell.NU, shell.GENERIC:
 		// Return the string and empty our buffer
 		str, _ := e.Writer.String()
 		return str
