@@ -128,6 +128,8 @@ const (
 	DART SegmentType = "dart"
 	// DENO writes the active deno version
 	DENO SegmentType = "deno"
+	// DOCKER writes the docker context
+	DOCKER SegmentType = "docker"
 	// DOTNET writes which dotnet version is currently active
 	DOTNET SegmentType = "dotnet"
 	// ELIXIR writes the elixir version
@@ -200,6 +202,8 @@ const (
 	RUBY SegmentType = "ruby"
 	// RUST writes the cargo version information if cargo.toml is present
 	RUST SegmentType = "rust"
+	// SAPLING represents the sapling segment
+	SAPLING SegmentType = "sapling"
 	// SESSION represents the user info segment
 	SESSION SegmentType = "session"
 	// SHELL writes which shell we're currently in
@@ -222,6 +226,8 @@ const (
 	TIME SegmentType = "time"
 	// UI5 Tooling segment
 	UI5TOOLING SegmentType = "ui5tooling"
+	// UNITY writes which Unity version is currently active
+	UNITY SegmentType = "unity"
 	// VALA writes the active vala version
 	VALA SegmentType = "vala"
 	// WAKATIME writes tracked time spend in dev editors
@@ -255,6 +261,7 @@ var Segments = map[SegmentType]func() SegmentWriter{
 	CMAKE:         func() SegmentWriter { return &segments.Cmake{} },
 	DART:          func() SegmentWriter { return &segments.Dart{} },
 	DENO:          func() SegmentWriter { return &segments.Deno{} },
+	DOCKER:        func() SegmentWriter { return &segments.Docker{} },
 	DOTNET:        func() SegmentWriter { return &segments.Dotnet{} },
 	EXECUTIONTIME: func() SegmentWriter { return &segments.Executiontime{} },
 	ELIXIR:        func() SegmentWriter { return &segments.Elixir{} },
@@ -291,6 +298,7 @@ var Segments = map[SegmentType]func() SegmentWriter{
 	ROOT:          func() SegmentWriter { return &segments.Root{} },
 	RUBY:          func() SegmentWriter { return &segments.Ruby{} },
 	RUST:          func() SegmentWriter { return &segments.Rust{} },
+	SAPLING:       func() SegmentWriter { return &segments.Sapling{} },
 	SESSION:       func() SegmentWriter { return &segments.Session{} },
 	SHELL:         func() SegmentWriter { return &segments.Shell{} },
 	SPOTIFY:       func() SegmentWriter { return &segments.Spotify{} },
@@ -302,6 +310,7 @@ var Segments = map[SegmentType]func() SegmentWriter{
 	TEXT:          func() SegmentWriter { return &segments.Text{} },
 	TIME:          func() SegmentWriter { return &segments.Time{} },
 	UI5TOOLING:    func() SegmentWriter { return &segments.UI5Tooling{} },
+	UNITY:         func() SegmentWriter { return &segments.Unity{} },
 	VALA:          func() SegmentWriter { return &segments.Vala{} },
 	WAKATIME:      func() SegmentWriter { return &segments.Wakatime{} },
 	WINREG:        func() SegmentWriter { return &segments.WindowsRegistry{} },
@@ -459,7 +468,7 @@ func (segment *Segment) SetEnabled(env platform.Environment) {
 	if toggles, OK := segment.env.Cache().Get(platform.TOGGLECACHE); OK && len(toggles) > 0 {
 		list := strings.Split(toggles, ",")
 		for _, toggle := range list {
-			if SegmentType(toggle) == segment.Type {
+			if SegmentType(toggle) == segment.Type || toggle == segment.Alias {
 				return
 			}
 		}
