@@ -71,6 +71,7 @@ type Flags struct {
 	PromptCount   int
 	Cleared       bool
 	Version       string
+	TrueColor     bool
 }
 
 type CommandError struct {
@@ -188,6 +189,7 @@ type TemplateCache struct {
 	OS           string
 	WSL          bool
 	PromptCount  int
+	SHLVL        int
 	Segments     SegmentsCache
 
 	sync.RWMutex
@@ -297,6 +299,14 @@ func (env *Shell) Init() {
 	if env.CmdFlags.Debug {
 		log.Enable()
 	}
+	if env.CmdFlags.Plain {
+		log.Plain()
+	}
+	trueColor := true
+	if env.Getenv("TERM_PROGRAM") == "Apple_Terminal" {
+		trueColor = false
+	}
+	env.CmdFlags.TrueColor = trueColor
 	env.fileCache = &fileCache{}
 	env.fileCache.Init(env.CachePath())
 	env.resolveConfigPath()
@@ -385,8 +395,9 @@ func (env *Shell) Getenv(key string) string {
 }
 
 func (env *Shell) Pwd() string {
+	env.Lock()
 	defer env.Trace(time.Now())
-	defer env.Debug(env.cwd)
+	defer env.Unlock()
 	if env.cwd != "" {
 		return env.cwd
 	}
@@ -400,6 +411,7 @@ func (env *Shell) Pwd() string {
 	}
 	if env.CmdFlags != nil && env.CmdFlags.PWD != "" {
 		env.cwd = correctPath(env.CmdFlags.PWD)
+		env.Debug(env.cwd)
 		return env.cwd
 	}
 	dir, err := os.Getwd()
@@ -408,6 +420,7 @@ func (env *Shell) Pwd() string {
 		return ""
 	}
 	env.cwd = correctPath(dir)
+	env.Debug(env.cwd)
 	return env.cwd
 }
 
@@ -633,7 +646,7 @@ func (env *Shell) Shell() string {
 	// this is used for when scoop creates a shim, see
 	// https://github.com/jandedobbeleer/oh-my-posh/issues/2806
 	executable, _ := os.Executable()
-	if name == "cmd.exe" || name == executable {
+	if name == executable {
 		p, _ = p.Parent()
 		name, err = p.Name()
 		env.Debug("parent process name: " + name)
@@ -763,9 +776,7 @@ func (env *Shell) Logs() string {
 }
 
 func (env *Shell) TemplateCache() *TemplateCache {
-	env.Lock()
 	defer env.Trace(time.Now())
-	defer env.Unlock()
 	if env.tmplCache != nil {
 		return env.tmplCache
 	}
@@ -814,6 +825,11 @@ func (env *Shell) TemplateCache() *TemplateCache {
 		tmplCache.OS = env.Platform()
 	}
 
+	val := env.Getenv("SHLVL")
+	if shlvl, err := strconv.Atoi(val); err == nil {
+		tmplCache.SHLVL = shlvl
+	}
+
 	env.tmplCache = tmplCache
 	return tmplCache
 }
